==> firefox-67.0.source.tar.xz: firefox-67.0/gfx/gl/TextureImageEGL.h <==
/* -*- Mode: C++; tab-width: 20; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef TEXTUREIMAGEEGL_H_
#define TEXTUREIMAGEEGL_H_

#include "GLTextureImage.h"

namespace mozilla {
namespace gl {

class TextureImageEGL final : public TextureImage {
 public:
  TextureImageEGL(
      GLuint aTexture, const gfx::IntSize& aSize, GLenum aWrapMode,
      ContentType aContentType, GLContext* aContext,
      Flags aFlags = TextureImage::NoFlags,
      TextureState aTextureState = Created,
      TextureImage::ImageFormat aImageFormat = SurfaceFormat::UNKNOWN);

  virtual ~TextureImageEGL();

  virtual bool DirectUpdate(
      gfx::DataSourceSurface* aSurf, const nsIntRegion& aRegion,
      const gfx::IntPoint& aFrom = gfx::IntPoint(0, 0)) override;

  virtual void BindTexture(GLenum aTextureUnit) override;

  virtual GLuint GetTextureID() override {
    // Ensure the texture is allocated before it is used.
    if (mTextureState == Created) {
      Resize(mSize);
    }
    return mTexture;
  };

  virtual void Resize(const gfx::IntSize& aSize) override;

  bool BindTexImage();

  bool ReleaseTexImage();

  virtual bool CreateEGLSurface(gfxASurface* aSurface) { return false; }

  virtual void DestroyEGLSurface(void);

 protected:
  typedef gfxImageFormat ImageFormat;

  GLContext* mGLContext;

  gfx::SurfaceFormat mUpdateFormat;
  EGLImage mEGLImage;
  GLuint mTexture;
  EGLSurface mSurface;
  EGLConfig mConfig;
  TextureState mTextureState;

  bool mBound;
};

already_AddRefed<TextureImage> CreateTextureImageEGL(
    GLContext* gl, const gfx::IntSize& aSize,
    TextureImage::ContentType aContentType, GLenum aWrapMode,
    TextureImage::Flags aFlags, TextureImage::ImageFormat aImageFormat);

already_AddRefed<TextureImage> TileGenFuncEGL(
    GLContext* gl, const gfx::IntSize& aSize,
    TextureImage::ContentType aContentType, TextureImage::Flags aFlags,
    TextureImage::ImageFormat aImageFormat);

}  // namespace gl
}  // namespace mozilla

#endif  // TEXTUREIMAGEEGL_H_

==> firefox-89.0b11.source.tar.xz: firefox-89.0/gfx/gl/TextureImageEGL.h <==
/* -*- Mode: C++; tab-width: 20; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef TEXTUREIMAGEEGL_H_
#define TEXTUREIMAGEEGL_H_

#include "GLTextureImage.h"

#include "mozilla/gfx/Types.h"

namespace mozilla {
namespace gl {

class TextureImageEGL final : public TextureImage {
 public:
  TextureImageEGL(
      GLuint aTexture, const gfx::IntSize& aSize, GLenum aWrapMode,
      ContentType aContentType, GLContext* aContext,
      Flags aFlags = TextureImage::NoFlags,
      TextureState aTextureState = Created,
      TextureImage::ImageFormat aImageFormat = gfx::SurfaceFormat::UNKNOWN);

  virtual ~TextureImageEGL();

  virtual bool DirectUpdate(
      gfx::DataSourceSurface* aSurf, const nsIntRegion& aRegion,
      const gfx::IntPoint& aFrom = gfx::IntPoint(0, 0)) override;

  virtual void BindTexture(GLenum aTextureUnit) override;

  virtual GLuint GetTextureID() override {
    // Ensure the texture is allocated before it is used.
    if (mTextureState == Created) {
      Resize(mSize);
    }
    return mTexture;
  };

  virtual void Resize(const gfx::IntSize& aSize) override;

  bool BindTexImage();

  bool ReleaseTexImage();

  virtual bool CreateEGLSurface(gfxASurface* aSurface) { return false; }

  virtual void DestroyEGLSurface(void);

 protected:
  typedef gfxImageFormat ImageFormat;

  GLContext* mGLContext;

  gfx::SurfaceFormat mUpdateFormat;
  EGLImage mEGLImage;
  GLuint mTexture;
  EGLSurface mSurface;
  EGLConfig mConfig;
  TextureState mTextureState;

  bool mBound;
};

already_AddRefed<TextureImage> CreateTextureImageEGL(
    GLContext* gl, const gfx::IntSize& aSize,
    TextureImage::ContentType aContentType, GLenum aWrapMode,
    TextureImage::Flags aFlags, TextureImage::ImageFormat aImageFormat);

already_AddRefed<TextureImage> TileGenFuncEGL(
    GLContext* gl, const gfx::IntSize& aSize,
    TextureImage::ContentType aContentType, TextureImage::Flags aFlags,
    TextureImage::ImageFormat aImageFormat);

}  // namespace gl
}  // namespace mozilla

#endif  // TEXTUREIMAGEEGL_H_
